MoveRect

Struct MoveRect 

pub struct MoveRect {
    pub source_point: (i32, i32),
    pub destination_rect: (i32, i32, i32, i32),
}
Available on Windows only.
Represents a rectangle that has been moved from one location to another.

This structure describes a region that was moved from a source location to a destination location, which is useful for optimizing screen updates in streaming applications.

Fields

source_point: (i32, i32)

The source point where the content was moved from (top-left corner)

destination_rect: (i32, i32, i32, i32)

The destination rectangle where the content was moved to